commit 5726535d9688d332fb3999c56b4b6963d01f1f5c
Author: Uwe Stöhr <uwesto...@lyx.org>
Date:   Sun Feb 9 23:17:38 2014 +0100

    BufferParams.cpp: fix bug #8613 also for branch

diff --git a/status.20x b/status.20x
index d7e0ca6..d9112aa 100644
--- a/status.20x
+++ b/status.20x
@@ -70,6 +70,8 @@ What's new
 
 - Fix drawing of table lines of multicolumns (bug 8082).
 
+- Correct language for textual references in multi-language documents (bug 
8613).
+
 - Handle undo in `branch-add' function.
 
 - Fix the missing dynamic menus in general and restore correctly from 
fullscreen.

Reply via email to
diff --git a/src/BufferParams.cpp b/src/BufferParams.cpp
index 71620c3..4aaf545 100644
--- a/src/BufferParams.cpp
+++ b/src/BufferParams.cpp
@@ -1743,10 +1743,12 @@ bool BufferParams::writeLaTeX(otexstream & os, 
LaTeXFeatures & features,
        // http://www.mail-archive.com/lyx-devel@lists.lyx.org/msg144349.html
        lyxpreamble += from_ascii(features.getColorOptions());
        
-       // If we use hyperref, jurabib, japanese, or vietnamese, we have to 
call babel before them.
+       // If we use hyperref, jurabib, japanese, varioref or vietnamese,
+       // we have to call babel before them.
        if (use_babel
            && (features.isRequired("jurabib")
                || features.isRequired("hyperref")
+               || features.isRequired("varioref") 
                || features.isRequired("vietnamese")
                || features.isRequired("japanese"))) {
                        // FIXME UNICODE
@@ -1894,9 +1896,10 @@ bool BufferParams::writeLaTeX(otexstream & os, 
LaTeXFeatures & features,
                        + atlyxpreamble + "\\makeatother\n\n";
 
        // We try to load babel late, in case it interferes with other packages.
        // Jurabib and Hyperref have to be called after babel, though.
        if (use_babel && !features.isRequired("jurabib")
            && !features.isRequired("hyperref")
+               && !features.isRequired("varioref")
            && !features.isRequired("vietnamese")
            && !features.isRequired("japanese")) {
                // FIXME UNICODE
@@ -1894,9 +1896,10 @@ bool BufferParams::writeLaTeX(otexstream & os, 
 
        // We try to load babel late, in case it interferes with other packages.
-       // Jurabib and Hyperref have to be called after babel, though.
+       // Jurabib, hyperref and varioref have to be called after babel, though.
        if (use_babel && !features.isRequired("jurabib")
            && !features.isRequired("hyperref")